@@ -8,8 +8,8 @@ use File::Spec;
 use File::Copy;
 
 my $MAJOR_VERSION = 1;
-my $MINOR_VERSION = 5;
-my $PATCH_VERSION = 13;
+my $MINOR_VERSION = 6;
+my $PATCH_VERSION = 2;
 
 my $VERSION_STRING = "$MAJOR_VERSION.$MINOR_VERSION.$PATCH_VERSION";
 
@@ -1492,8 +1492,13 @@ sub generate_makefile {
        'install_group' => os_info_for($os, 'install_group'),
        });
 
+   my $is_in_doc_dir =
+       sub { -e File::Spec->catfile($$config{'doc-dir'}, $_[0]) };
+
    my $docs = file_list(undef, undef, undef,
-                        map_to($$config{'doc-dir'}, @DOCS));
+                        map_to($$config{'doc-dir'},
+                               grep { &$is_in_doc_dir($_); } @DOCS));
+
    $docs .= File::Spec->catfile($$config{'base-dir'}, 'readme.txt');
 
    my $includes = file_list(undef, undef, undef,
@@ -1578,8 +1583,9 @@ sub guess_cpu_from_this
 
     $cpu = 'core2duo' if($cpuinfo =~ /intel\(r\) core\(tm\)2/);
 
-    $cpu = 'amd64' if($cpuinfo =~ /athlon64/);
-    $cpu = 'amd64' if($cpuinfo =~ /opteron/);
+    $cpu = 'athlon64' if($cpuinfo =~ /athlon64/);
+    $cpu = 'athlon64' if($cpuinfo =~ /athlon\(tm\) 64/);
+    $cpu = 'opteron' if($cpuinfo =~ /opteron/);
 
     # The 32-bit SPARC stuff is impossible to match to arch type easily, and
     # anyway the uname stuff will pick up that it's a SPARC so it doesn't
