@@ -1,6 +1,6 @@
 /*************************************************
 * GMP Engine Header File                         *
-* (C) 1999-2005 The Botan Project                *
+* (C) 1999-2007 The Botan Project                *
 *************************************************/
 
 #ifndef BOTAN_EXT_ENGINE_GMP_H__
@@ -30,7 +30,8 @@ class GMP_Engine : public Engine
 
       DH_Operation* dh_op(const DL_Group&, const BigInt&) const;
 
-      ModularReducer* reducer(const BigInt&, bool) const;
+      Modular_Exponentiator* mod_exp(const BigInt&,
+                                     Power_Mod::Usage_Hints) const;
 
       GMP_Engine();
    private:
